DPS Titan 8 Wi-Fi 4GB - Tablet PC: árak, összehasonlítás - Olcsóbbat.hu
Description: DPS Titan 8 Wi-Fi 4GB - 9 webshop árajánlata, 1 értékelés. DPS Titan 8 Wi-Fi 4GB jellemzői, vásárlási tanácsok, boltok rendezése árak szerint.

Te már mindent megvettél Karácsonyra? Ajándékkereső oldalunkon sok tippet találsz! | Már csak 13 napod maradt!

- Olcsóbbat.hu - Spórolni tudni kell!

- További kategóriák

Előző termék
LG G Pad 8.3
60 000 Ft-tól
Következő termék
Samsung Galaxy Tab 4 10.1 T535 LTE 16GB
83 100 Ft-tól

Top 8

1 kép
DPS Titan 8 Wi-Fi 4GB
Kiemelt ajánlataink:

| 22 900 Ft | »
| 19 900 Ft | »
| 19 900 Ft | »

Hirdetés

# DPS Titan 8 Wi-Fi 4GB Tablet PC

1 vélemény Írj véleményt!

19 900 Ft-tól 12 ajánlat

- Órajel: 1 500 MHz,
- Operációs rendszer: Android,
- Belső memória mérete: 4 GB,
- Kijelző felbontása: 1024 x 768,
- Kijelző mérete: 7,85 inch,
- Bluetooth: igen,
- WiFi: igen,
- 3G: nem

tovább

- Árak összehasonlítása
- Termékleírás
- Vélemények 1

Rendezés:
Fizetési mód:
Személyesen átvehető itt:
Bolt:
Megbízható bolt (6) Ingyenes szállítás (1)
Tartózkodási helyed:

## DPS Titan 8 Wi-Fi 4GB tablet pc ajánlataink

- 25 vélemény

  Megbízható bolt
  Megbízható webáruház
  Az Olcsóbbat.hu próbavásárlással tesztelte ezt az áruházat, ezért kiemelten ajánljuk.

  DPS Titan 8

  Ingyenes szállítás, 1 nap alatt

  Személyes átvét, Futár, PickPack

  Kártya, Utalás, Utánvét, Készpénz

  Több info >>
  22 900 Ft

- 33 vélemény

  Megbízható bolt
  Megbízható webáruház
  Az Olcsóbbat.hu próbavásárlással tesztelte ezt az áruházat, ezért kiemelten ajánljuk.

  DPS Titan 8

  Személyes átvét, Futár

  Utalás, Utánvét, Készpénz

  Több info >>
  19 900 Ft

- 64 vélemény

  Megbízható bolt
  Megbízható webáruház
  Az Olcsóbbat.hu próbavásárlással tesztelte ezt az áruházat, ezért kiemelten ajánljuk.

  DPS Titan 8

  Személyes átvét, Futár

  Utalás, Utánvét, Készpénz

  Több info >>
  19 900 Ft

## További ajánlataink

- 23 vélemény

  Megbízható bolt
  Megbízható webáruház
  Az Olcsóbbat.hu próbavásárlással tesztelte ezt az áruházat, ezért kiemelten ajánljuk.

  DPS Titan 8

  Személyes átvét, Futár

  Utalás, Utánvét, Készpénz

  Több info >>
  19 900 Ft

- Írj véleményt!

  DPS TITAN8
  Magyar márkagarancia - Gyors kiszállítás

  Kiszállítás díja 990 Ft

  Raktáron
  Több info >>
  19 900 Ft

- 8 vélemény

  DPS Titan 8 8" 4GB tablet

  Kiszállítás díja 690 Ft, 5 nap alatt

  Személyes átvét, Futár, PickPack

  Kártya, Utalás, Utánvét, Készpénz

  Több info >>
  24 990 Ft

- 1 vélemény

  DPS Titan 8

  Készpénz

  Több info >>
  24 999 Ft

- 4 vélemény

  DPS Titan 8

  Kiszállítás díja 2 000 Ft, 1 nap alatt

  Személyes átvét, Futár

  Kártya, Utalás, Utánvét, Készpénz

  Több info >>
  28 301 Ft

- 3 vélemény

  DPS Titan 8" 4GB IPS tablet

  Kiszállítás díja 990 Ft, 1 nap alatt

  Személyes átvét, Futár

  Kártya, Utalás, Utánvét, Készpénz

  Raktáron
  Több info >>
  28 999 Ft

- 49 vélemény

  Megbízható bolt
  Megbízható webáruház
  Az Olcsóbbat.hu próbavásárlással tesztelte ezt az áruházat, ezért kiemelten ajánljuk.

  TABLET DPS Titan 8" 4GB IPS

  Kiszállítás díja 1 990 Ft

  Személyes átvét, Futár, PickPack

  Kártya, Utalás, Utánvét, Készpénz

  Több info >>
  29 330 Ft

- 1 vélemény

  DPS Titan 8

  Személyes átvét, Futár

  Utalás, Utánvét, Készpénz

  Több info >>
  30 620 Ft

- 10 vélemény

  Megbízható bolt
  Megbízható webáruház
  Az Olcsóbbat.hu próbavásárlással tesztelte ezt az áruházat, ezért kiemelten ajánljuk.

  DPS Titan 8 Tablet

  Személyes átvét, Futár, PickPack

  Kártya, Utalás, Utánvét, Készpénz

  Raktáron
  Több info >>
  33 490 Ft

## DPS Titan 8 Wi-Fi 4GB tablet pc termékleírás

| Processzor típusa | ARM Cortex A23
Processzormagok száma A többmagos processzorok előnye, hogy egyidejűleg több végrehajtási szálat képesek párhuzamosan feldolgozni. Egy processzorba épített két magnak köszönhetően az egyidejű számítások megduplázódnak, egy azonos órajelű, egymagos processzorhoz képest. Ennek ellenére a kétszeres gyorsulás ritkán érzékelhető a gyakorlatban, mert különböző programok különböző mértékben képesek profitálni belőle. | Processzormagok száma | 2
Órajel A processzorok sebességét általában megahertz-ben (MHz) mérik. Minél nagyobb egy processzor órajele, az annál gyorsabb működést biztosít. | Órajel | 1 500 MHz
| RAM mérete | 1 GB

Teljes DPS Titan 8 Wi-Fi 4GB termékleírás

## DPS Titan 8 Wi-Fi 4GB tablet pc árgrafikon

Árfigyelés

## Van véleményed a DPS Titan 8 Wi-Fi 4GB termékről? Értékeld!

1 vélemény

0 Kiváló 0 Nagyon jó 1 Átlagos 0 Gyenge 0 Rossz | #### Szabó Pál

További vélemények: DPS Titan 8 Wi-Fi 4GB

## Hasonló tulajdonságokkal rendelkező tablet pc-k

Archos 28 4GB
25 900 Ft-tól
Archos 32 4GB
30 900 Ft-tól
Arnova 7 G2 8GB
27 590 Ft-tól
Archos Arnova 10B G3 4GB
36 190 Ft-tól
Funscreen funtab LUNA 7R22
25 990 Ft-tól
NAVON Platinum 7 4GB
30 490 Ft-tól

## Kapcsolódó kategóriák

- Tablet tok
- Memóriakártya
- Tablet kellék
- Fülhallgató, fejhallgató
- Mobiltelefon
- e-Book olvasó
- Billentyűzet
- Egér
- Monitor
- Pendrive
- Kábel és adapter
- Laptop

- Olcsóbbat közösség
- Blog
- Facebook
- iPhone app
- Android app
- Mobil nézet

- Spórolni tudni kell!
- Új termékek
- Népszerű termékek
- Gyártók
- Boltok
- Mobilnet

- Hasznos
- Vásárlási tanácsok
- Segítség
- Felhasználási feltételek
- Adatvédelem
- Impresszum

- Csatlakozz hozzánk!
- Belépés boltoknak
- Információ boltoknak
- Regisztráció boltoknak
- Webshopot szeretne?
- ÁSZF

## Hírlevél feliratkozás

Olcsóbbat.hu - © 2005-2014 Central Médiacsoport Zrt.

Elrejt Nagyít +

- ### Utoljára megtekintett (0)

  Összes törlése
  0 Utoljára megtekintett

- ### Árfigyelés (0)

  Összes törlése
  Az Árfigyelés beállítással időben értesülhetsz, ha a figyelt termék a megadott ár alá csökkent.
  Minden kiválasztott terméket 30 napig figyelünk Neked!
  Ahhoz, hogy itt is lásd beállított árfigyeléseidet regisztrálj, vagy lépj be.
  0 Árfigyelés

- Bejelentkezés | Regisztráció

- Termékkategóriák:

Összehasonlítom
Összes elem eltávolítása

### Olcsóbbat.hu eszköztára

segítségével beállíthatsz árfigyelést, összehasonlíthatsz termékeket...

| Bezár

### Olcsóbbat.hu eszköztára

segítségével beállíthatsz árfigyelést, összehasonlíthatsz termékeket...

| Kinyit